<?php

/**
 * EventSelectionLinkHandler.
 */
declare(strict_types=1);

namespace HDNET\Calendarize\LinkHandling;

use Psr\Http\Message\ServerRequestInterface;
use TYPO3\CMS\Backend\Tree\View\ElementBrowserPageTreeView;
use TYPO3\CMS\Core\Page\PageRenderer;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Recordlist\LinkHandler\PageLinkHandler;

/**
 * EventSelectionLinkHandler.
 */
class EventSelectionLinkHandler extends PageLinkHandler
{
    /**
     * Parts of the current link.
     *
     * @var array
     */
    protected $linkParts = [];

    /**
     * Checks if this is the handler for the given link.
     *
     * The handler may store this information locally for later usage.
     *
     * @param array $linkParts Link parts as returned from TypoLinkCodecService
     *
     * @return bool
     */
    public function canHandleLink(array $linkParts)
    {
        $this->linkParts = $linkParts;

        return true;
    }

    /**
     * Format the current link for HTML output.
     *
     * @return string
     */
    public function formatCurrentUrl()
    {
        return '';
    }

    /**
     * Render the link handler.
     *
     * @param ServerRequestInterface $request
     *
     * @return string
     */
    public function render(ServerRequestInterface $request)
    {
        GeneralUtility::makeInstance(PageRenderer::class)->loadRequireJsModule('TYPO3/CMS/Recordlist/PageLinkHandler');

        $this->expandPage = isset($request->getQueryParams()['expandPage']) ? (int) $request->getQueryParams()['expandPage'] : 0;
        $this->setTemporaryDbMounts();

        $backendUser = $this->getBackendUser();

        /** @var ElementBrowserPageTreeView $pageTree */
        $pageTree = GeneralUtility::makeInstance(ElementBrowserPageTreeView::class);
        $pageTree->setLinkParameterProvider($this);
        $pageTree->ext_showNavTitle = (bool) $backendUser->getTSConfigVal('options.pageTree.showNavTitle');
        $pageTree->ext_showPageId = (bool) $backendUser->getTSConfigVal('options.pageTree.showPageIdWithTitle');
        $pageTree->ext_showPathAboveMounts = (bool) $backendUser->getTSConfigVal('options.pageTree.showPathAboveMounts');
        $pageTree->addField('nav_title');

        $this->view->assign('temporaryTreeMountCancelLink', $this->getTemporaryTreeMountCancelNotice());
        $this->view->assign('tree', $pageTree->getBrowsableTree());
        $this->getRecordsOnExpandedPage($this->expandPage);

        return $this->view->render('Page');
    }

    /**
     * Get array of body tag attributes.
     *
     * @return string[]
     */
    public function getBodyTagAttributes()
    {
        return [];
    }
}
